@@ -33,7 +33,7 @@
 #include <kogradientmanager.h>
 
 #include <kdebug.h>
-#include <klocale.h>
+#include <tdelocale.h>
 
 #include "kis_gradient.h"
 
@@ -103,7 +103,7 @@ bool KisGradient::init()
                 Color rightColor(rightRgb.color(), colstopNext->opacity);
 
                 KisGradientSegment *segment = new KisGradientSegment(colstop->interpolation, colstop->colorType, colstop->offset, midp, colstopNext->offset, leftColor, rightColor);
-                Q_CHECK_PTR(segment);
+                TQ_CHECK_PTR(segment);
 
                 if ( !segment->isValid() ) {
                     delete segment;
@@ -418,7 +418,7 @@ KisGradientSegment::RGBColorInterpolationStrategy *KisGradientSegment::RGBColorI
 {
     if (m_instance == 0) {
         m_instance = new RGBColorInterpolationStrategy();
-        Q_CHECK_PTR(m_instance);
+        TQ_CHECK_PTR(m_instance);
     }
 
     return m_instance;
@@ -442,7 +442,7 @@ KisGradientSegment::HSVCWColorInterpolationStrategy *KisGradientSegment::HSVCWCo
 {
     if (m_instance == 0) {
         m_instance = new HSVCWColorInterpolationStrategy();
-        Q_CHECK_PTR(m_instance);
+        TQ_CHECK_PTR(m_instance);
     }
 
     return m_instance;
@@ -477,7 +477,7 @@ KisGradientSegment::HSVCCWColorInterpolationStrategy *KisGradientSegment::HSVCCW
 {
     if (m_instance == 0) {
         m_instance = new HSVCCWColorInterpolationStrategy();
-        Q_CHECK_PTR(m_instance);
+        TQ_CHECK_PTR(m_instance);
     }
 
     return m_instance;
@@ -512,7 +512,7 @@ KisGradientSegment::LinearInterpolationStrategy *KisGradientSegment::LinearInter
 {
     if (m_instance == 0) {
         m_instance = new LinearInterpolationStrategy();
-        Q_CHECK_PTR(m_instance);
+        TQ_CHECK_PTR(m_instance);
     }
 
     return m_instance;
@@ -559,7 +559,7 @@ KisGradientSegment::CurvedInterpolationStrategy *KisGradientSegment::CurvedInter
 {
     if (m_instance == 0) {
         m_instance = new CurvedInterpolationStrategy();
-        Q_CHECK_PTR(m_instance);
+        TQ_CHECK_PTR(m_instance);
     }
 
     return m_instance;
@@ -585,7 +585,7 @@ KisGradientSegment::SineInterpolationStrategy *KisGradientSegment::SineInterpola
 {
     if (m_instance == 0) {
         m_instance = new SineInterpolationStrategy();
-        Q_CHECK_PTR(m_instance);
+        TQ_CHECK_PTR(m_instance);
     }
 
     return m_instance;
@@ -603,7 +603,7 @@ KisGradientSegment::SphereIncreasingInterpolationStrategy *KisGradientSegment::S
 {
     if (m_instance == 0) {
         m_instance = new SphereIncreasingInterpolationStrategy();
-        Q_CHECK_PTR(m_instance);
+        TQ_CHECK_PTR(m_instance);
     }
 
     return m_instance;
@@ -621,7 +621,7 @@ KisGradientSegment::SphereDecreasingInterpolationStrategy *KisGradientSegment::S
 {
     if (m_instance == 0) {
         m_instance = new SphereDecreasingInterpolationStrategy();
-        Q_CHECK_PTR(m_instance);
+        TQ_CHECK_PTR(m_instance);
     }
 
     return m_instance;
