@@ -19,12 +19,12 @@
 #ifndef SELECTSIMILAR_H
 #define SELECTSIMILAR_H
 
-#include <kparts/plugin.h>
+#include <tdeparts/plugin.h>
 
 class SelectSimilar : public KParts::Plugin
 {
         Q_OBJECT
-  TQ_OBJECT
+  
     public:
         SelectSimilar(TQObject *parent, const char *name, const TQStringList &);
         virtual ~SelectSimilar();
