@@ -23,7 +23,7 @@
 
 #include <kdebug.h>
 #include <kinputdialog.h>
-#include <kapplication.h>
+#include <tdeapplication.h>
 
 #include <kexiutils/identifier.h>
 #include <core/kexi.h>
