@@ -24,21 +24,21 @@
 
 #include <klibloader.h>
 
-class KInstance;
+class TDEInstance;
 
 class ZoomToolFactory : public KLibFactory
 { Q_OBJECT
-  TQ_OBJECT
+  
 public:
   ZoomToolFactory( TQObject* parent = 0, const char* name = 0 );
   ~ZoomToolFactory();
 
   virtual TQObject* createObject( TQObject* parent = 0, const char* name = 0,
                            const char* classname = TQOBJECT_OBJECT_NAME_STRING, const TQStringList &args = TQStringList() );
-  static KInstance* global();
+  static TDEInstance* global();
 
 private:
-  static KInstance* s_global;
+  static TDEInstance* s_global;
 };
 
 #endif
