@@ -34,15 +34,15 @@
 #include <KoSpeaker.h>
 
 // KDE includes.
-#include <klocale.h>
+#include <tdelocale.h>
 #include <kiconloader.h>
 #include <kdebug.h>
-#include <klistviewsearchline.h>
-#include <kglobalsettings.h>
-#include <kglobal.h>
+#include <tdelistviewsearchline.h>
+#include <tdeglobalsettings.h>
+#include <tdeglobal.h>
 #include <kpixmap.h>
-#include <ktoolbar.h>
-#include <ktoolbarbutton.h>
+#include <tdetoolbar.h>
+#include <tdetoolbarbutton.h>
 
 #include <tqlayout.h>
 
@@ -75,17 +75,17 @@ bool KWOrderedFrameSet::operator<( KWOrderedFrameSet ofs )
 /******************************************************************/
 
 KWDocListViewItem::KWDocListViewItem(TQListViewItem* parent, const TQString& text)
-    : KListViewItem(parent, text)
+    : TDEListViewItem(parent, text)
 {
 }
 
 KWDocListViewItem::KWDocListViewItem(TQListViewItem* parent, TQListViewItem* after, const TQString& text )
-    :KListViewItem(parent, after, text)
+    :TDEListViewItem(parent, after, text)
 {
 }
 
 KWDocListViewItem::KWDocListViewItem(TQListView* parent, const TQString& text)
-    :KListViewItem(parent, text)
+    :TDEListViewItem(parent, text)
 {
 }
 
@@ -382,7 +382,7 @@ void KWDocStructTextFrameSetItem::setupTextFrames()
     {
         KWFrame* frame = framePtrs.at(j);
         TQString name;
-        if ( KListViewItem::parent()->firstChild() == this && dok->processingType() == KWDocument::WP )
+        if ( TDEListViewItem::parent()->firstChild() == this && dok->processingType() == KWDocument::WP )
         {
             if ( dok->numColumns() == 1 )
                 name=i18n( "Page %1" ).arg(TQString::number(j + 1));
@@ -721,22 +721,22 @@ KWDocStructRootItem::KWDocStructRootItem(TQListView* parent, const TQString& tex
 {
     switch ( type ) {
         case Arrangement: {
-            setPixmap( 0, KGlobal::iconLoader()->loadIcon( "tree_arrange", KIcon::Small ) );
+            setPixmap( 0, TDEGlobal::iconLoader()->loadIcon( "tree_arrange", TDEIcon::Small ) );
         } break;
         case TextFrames: {
-            setPixmap( 0, KGlobal::iconLoader()->loadIcon( "frame_text", KIcon::Small ) );
+            setPixmap( 0, TDEGlobal::iconLoader()->loadIcon( "frame_text", TDEIcon::Small ) );
         } break;
         case FormulaFrames: {
-            setPixmap( 0, KGlobal::iconLoader()->loadIcon( "frame_formula", KIcon::Small ) );
+            setPixmap( 0, TDEGlobal::iconLoader()->loadIcon( "frame_formula", TDEIcon::Small ) );
         }break;
         case Tables: {
-            setPixmap( 0, KGlobal::iconLoader()->loadIcon( "inline_table", KIcon::Small ) );
+            setPixmap( 0, TDEGlobal::iconLoader()->loadIcon( "inline_table", TDEIcon::Small ) );
         } break;
         case Pictures: {
-            setPixmap( 0, KGlobal::iconLoader()->loadIcon( "frame_image", KIcon::Small ) );
+            setPixmap( 0, TDEGlobal::iconLoader()->loadIcon( "frame_image", TDEIcon::Small ) );
         } break;
         case Embedded: {
-            setPixmap( 0, KGlobal::iconLoader()->loadIcon( "frame_query", KIcon::Small ) );
+            setPixmap( 0, TDEGlobal::iconLoader()->loadIcon( "frame_query", TDEIcon::Small ) );
         } break;
     }
 }
@@ -823,7 +823,7 @@ void KWDocStructRootItem::setupArrangement()
     }
 
     if ( childCount() == 0 )
-        ( void )new KListViewItem( this, i18n( "Empty" ) );
+        ( void )new TDEListViewItem( this, i18n( "Empty" ) );
 
 }
 
@@ -881,7 +881,7 @@ void KWDocStructRootItem::setupTextFrameSets()
     }
 
     if ( childCount() == 0 )
-        ( void )new KListViewItem( this, i18n( "Empty" ) );
+        ( void )new TDEListViewItem( this, i18n( "Empty" ) );
 }
 
 void KWDocStructRootItem::setupFormulaFrames()
@@ -905,7 +905,7 @@ void KWDocStructRootItem::setupFormulaFrames()
     }
 
     if ( childCount() == 0 )
-        ( void )new KListViewItem( this, i18n( "Empty" ) );
+        ( void )new TDEListViewItem( this, i18n( "Empty" ) );
 }
 
 void KWDocStructRootItem::setupTables()
@@ -959,7 +959,7 @@ void KWDocStructRootItem::setupTables()
     }
 
     if ( childCount() == 0 )
-        ( void )new KListViewItem( this, i18n( "Empty" ) );
+        ( void )new TDEListViewItem( this, i18n( "Empty" ) );
 }
 
 void KWDocStructRootItem::setupPictures()
@@ -983,7 +983,7 @@ void KWDocStructRootItem::setupPictures()
     }
 
     if ( childCount() == 0 )
-        ( void )new KListViewItem( this, i18n( "Empty" ) );
+        ( void )new TDEListViewItem( this, i18n( "Empty" ) );
 }
 
 void KWDocStructRootItem::setupEmbedded()
@@ -1007,7 +1007,7 @@ void KWDocStructRootItem::setupEmbedded()
     }
 
     if ( childCount() == 0 )
-        ( void )new KListViewItem( this, i18n( "Empty" ) );
+        ( void )new TDEListViewItem( this, i18n( "Empty" ) );
 }
 
 KWDocStructTextFrameSetItem* KWDocStructRootItem::findTextFrameSetItem(const KWFrameSet* frameset)
@@ -1047,7 +1047,7 @@ KWDocStructTableItem* KWDocStructRootItem::findTableItem(const KWFrameSet* frame
 /******************************************************************/
 
 KWDocStructTree::KWDocStructTree(TQWidget* parent, KWDocument* doc, KWGUI* gui)
-    : KListView(parent), m_doc(doc), m_gui(gui)
+    : TDEListView(parent), m_doc(doc), m_gui(gui)
 {
     embedded = new KWDocStructRootItem( this, i18n( "Embedded Objects" ), Embedded);
     formulafrms = new KWDocStructRootItem( this, i18n( "Formula Frames" ), FormulaFrames);
@@ -1065,8 +1065,8 @@ KWDocStructTree::KWDocStructTree(TQWidget* parent, KWDocument* doc, KWGUI* gui)
         this, TQT_SLOT( slotReturnPressed(TQListViewItem* )) );
     connect( this, TQT_SIGNAL(rightButtonClicked(TQListViewItem*, const TQPoint&,int)),
         this, TQT_SLOT( slotRightButtonClicked(TQListViewItem *, const TQPoint&, int)));
-    connect( this, TQT_SIGNAL(contextMenu(KListView*, TQListViewItem*, const TQPoint&)),
-        this, TQT_SLOT(slotContextMenu(KListView*, TQListViewItem*, const TQPoint&)) );
+    connect( this, TQT_SIGNAL(contextMenu(TDEListView*, TQListViewItem*, const TQPoint&)),
+        this, TQT_SLOT(slotContextMenu(TDEListView*, TQListViewItem*, const TQPoint&)) );
 }
 
 KWDocStructTree::~KWDocStructTree()
@@ -1150,7 +1150,7 @@ void KWDocStructTree::speakItem()
         tmp->speakItem();
 }
 
-void KWDocStructTree::slotContextMenu(KListView* lv, TQListViewItem* i, const TQPoint& p)
+void KWDocStructTree::slotContextMenu(TDEListView* lv, TQListViewItem* i, const TQPoint& p)
 {
     if (lv != this)
         return;
@@ -1193,14 +1193,14 @@ KWDocStruct::KWDocStruct(TQWidget* parent, KWDocument* doc, KWGUI* gui)
 {
     m_layout = new TQVBoxLayout( this );
 
-    KToolBar* searchBar = new KToolBar( this );
+    TDEToolBar* searchBar = new TDEToolBar( this );
     searchBar->setFlat( true );
     searchBar->setMovingEnabled( false );
 
-    KToolBarButton* eraseButton = new KToolBarButton( "locationbar_erase", 0, searchBar );
+    TDEToolBarButton* eraseButton = new TDEToolBarButton( "locationbar_erase", 0, searchBar );
     m_tree = new KWDocStructTree( this, doc, gui );
-    m_tree->setAlternateBackground( KGlobalSettings::alternateBackgroundColor() );
-    KListViewSearchLine* searchLine = new KListViewSearchLine( searchBar, m_tree );
+    m_tree->setAlternateBackground( TDEGlobalSettings::alternateBackgroundColor() );
+    TDEListViewSearchLine* searchLine = new TDEListViewSearchLine( searchBar, m_tree );
     searchBar->setStretchableWidget( searchLine );
     connect( eraseButton, TQT_SIGNAL( clicked() ), searchLine, TQT_SLOT( clear() ) );
 
